/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

#ifndef _NO_PROTO
Widget 
CreateSpecialWarningDialog (Widget parent, String name, String image_string,
			    String message, ArgList arglist, int argcount);
int             XmNotImplementedYet (char *Title);
int             NICB (Widget w, caddr_t client_data, caddr_t call_data);
int             XmErr (int ErrorCode);
#else
Widget          CreateSpecialWarningDialog ();
int             XmNotImplementedYet ();
int             NICB ();
int             XmErr ();
#endif

#define NOT_IMPLEMENTED 1
#define FILE_NOT_FOUND 2
#define EMPTY_STRING 3
#define NO_IMAGE_PRESENT 4
#define NUMBER_TO_BIG 5
#define IMAGE_FORMAT 6
#define MONO_SCREEN 7
#define MONO_NOSAVE 8
#define NO_SET 9
#define NOT_IN_THIS_MODE 10
#define IMPORT_ERROR 11
#define NO_COMPRESSIONCMD 12
#define PARM_OUT_OF_DATE 13
